==> pw-iso20022-SRU2022-9.3.2-sources.jar: com/prowidesoftware/swift/model/mx/sys/dic/SwHSMManagePartitionsResponse.java <==

package com.prowidesoftware.swift.model.mx.sys.dic;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Java class for HSMManagePartitionsResponse complex type.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HSMManagePartitionsResponse", propOrder = {
    "actionCode",
    "hsmPartitionList",
    "partitionName"
})
public class SwHSMManagePartitionsResponse {

    @XmlElement(name = "ActionCode", required = true)
    protected String actionCode;
    @XmlElement(name = "HSMPartitionList")
    protected SwHSMPartitionList hsmPartitionList;
    @XmlElement(name = "PartitionName")
    protected String partitionName;

    /**
     * Gets the value of the actionCode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActionCode() {
        return actionCode;
    }

    /**
     * Sets the value of the actionCode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public SwHSMManagePartitionsResponse setActionCode(String value) {
        this.actionCode = value;
        return this;
    }

    /**
     * Gets the value of the hsmPartitionList property.
     * 
     * @return
     *     possible object is
     *     {@link SwHSMPartitionList }
     *     
     */
    public SwHSMPartitionList getHSMPartitionList() {
        return hsmPartitionList;
    }

    /**
     * Sets the value of the hsmPartitionList property.
     * 
     * @param value
     *     allowed object is
     *     {@link SwHSMPartitionList }
     *     
     */
    public SwHSMManagePartitionsResponse setHSMPartitionList(SwHSMPartitionList value) {
        this.hsmPartitionList = value;
        return this;
    }

    /**
     * Gets the value of the partitionName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPartitionName() {
        return partitionName;
    }

    /**
     * Sets the value of the partitionName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public SwHSMManagePartitionsResponse setPartitionName(String value) {
        this.partitionName = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}

==> pw-iso20022-SRU2024-10.2.4-sources.jar: com/prowidesoftware/swift/model/mx/sys/dic/SwHSMManagePartitionsResponse.java <==

package com.prowidesoftware.swift.model.mx.sys.dic;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;
import org.apache.commons.lang3.builder.EqualsBuilder;
import org.apache.commons.lang3.builder.HashCodeBuilder;
import org.apache.commons.lang3.builder.ToStringBuilder;
import org.apache.commons.lang3.builder.ToStringStyle;


/**
 * Java class for HSMManagePartitionsResponse complex type.
 * 
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HSMManagePartitionsResponse", propOrder = {
    "actionCode",
    "hsmPartitionList",
    "partitionName"
})
public class SwHSMManagePartitionsResponse {

    @XmlElement(name = "ActionCode", required = true)
    protected String actionCode;
    @XmlElement(name = "HSMPartitionList")
    protected SwHSMPartitionList hsmPartitionList;
    @XmlElement(name = "PartitionName")
    protected String partitionName;

    /**
     * Gets the value of the actionCode property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getActionCode() {
        return actionCode;
    }

    /**
     * Sets the value of the actionCode property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public SwHSMManagePartitionsResponse setActionCode(String value) {
        this.actionCode = value;
        return this;
    }

    /**
     * Gets the value of the hsmPartitionList property.
     * 
     * @return
     *     possible object is
     *     {@link SwHSMPartitionList }
     *     
     */
    public SwHSMPartitionList getHSMPartitionList() {
        return hsmPartitionList;
    }

    /**
     * Sets the value of the hsmPartitionList property.
     * 
     * @param value
     *     allowed object is
     *     {@link SwHSMPartitionList }
     *     
     */
    public SwHSMManagePartitionsResponse setHSMPartitionList(SwHSMPartitionList value) {
        this.hsmPartitionList = value;
        return this;
    }

    /**
     * Gets the value of the partitionName property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getPartitionName() {
        return partitionName;
    }

    /**
     * Sets the value of the partitionName property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public SwHSMManagePartitionsResponse setPartitionName(String value) {
        this.partitionName = value;
        return this;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this, ToStringStyle.MULTI_LINE_STYLE);
    }

    @Override
    public boolean equals(Object that) {
        return EqualsBuilder.reflectionEquals(this, that);
    }

    @Override
    public int hashCode() {
        return HashCodeBuilder.reflectionHashCode(this);
    }

}
